/**
  *  \file client/tiles/taskedittile.h
  *  \brief WAutoTaskEditorTile tile
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_TILES_TASKEDITTILE_H
#define PCC_V2_CLIENT_TILES_TASKEDITTILE_H

#include "client/wtile.h"
#include "cpluslib/sigslot.h"

class WAutoTaskObjectSelection;
class WAutoTaskEditorList;
class GObjectSelection;

/** Auto task editor tile. This tile observes a WAutoTaskObjectSelection,
    and displays a WAutoTaskEditorList. It hooks these two together so
    that the list always displays the current task, and cursors are in
    sync.

    This tile cannot meaningfully be used on an object selection other than
    a WAutoTaskObjectSelection. It will display just blank space if it is
    used thus. */
class WAutoTaskEditorTile : public WTile {
    ObjectHolder holder;

    WAutoTaskObjectSelection* atsel;
    WAutoTaskEditorList* atlist;
    SignalConnection conn_task_changed;

    void init();

    void onListMoved();
    void onTaskChanged(bool newTask);

 public:
    WAutoTaskEditorTile(GObjectSelection& selection);
    ~WAutoTaskEditorTile();

    void drawData(GfxCanvas& can);
};

#endif
